# BPMN → Neo4j Graph Transformation

A lightweight Python library to transform **BPMN JSON** into **Cypher queries** for Neo4j.

## ✨ Features
- Convert BPMN JSON into Neo4j graph
- Schema & semantic validation for BPMN
- Transformations for nodes, edges, pools, and lanes

## 📦 Installation
```bash
pip install bpmn-graph-transformation
```

## 📖 Documentation
<a href="https://gitlab.iimlab.id/business-process/LIBRARY-BPMN_Graph_Transformation" target="_blank">
Full Documentation & Source Code
</a>
